@@ -9,18 +9,14 @@ import redis
 from diagrams import Diagram, Edge, Cluster
 from diagrams.onprem.queue import Kafka
 from diagrams.onprem.container import Docker
-from diagrams.programming.flowchart import Database
+from diagrams.programming.flowchart import Database, MultipleDocuments
 from diagrams.elastic.elasticsearch import Elasticsearch, Kibana, Logstash
-from diagrams.programming.framework import React
-from diagrams.programming.framework import Django
-from diagrams.onprem.network import Nginx
+from diagrams.programming.framework import React, Django, Flask
 from diagrams.aws.engagement import SimpleEmailServiceSesEmail
-from diagrams.programming.flowchart import MultipleDocuments
 from diagrams.onprem.compute import Server
 from diagrams.onprem.client import Users
-from diagrams.onprem.network import Internet
+from diagrams.onprem.network import Internet, Haproxy, Nginx
 from diagrams.onprem.inmemory import Redis
-from diagrams.onprem.network import Haproxy
 from diagrams.custom import Custom
 
 import pkg_resources
@@ -524,8 +520,12 @@ class ArchitectureAsCode:
                             architecture[service_name] = Django(clean_service_name(service_name))
                         elif 'django' in service_name.lower():
                             architecture[service_name] = Django(clean_service_name(service_name))
+                        elif 'flask' in service_name.lower():
+                            architecture[service_name] = Flask(clean_service_name(service_name))
                         elif 'web-server' in service_name.lower():
                             architecture[service_name] = Nginx(clean_service_name(service_name))
+                        elif 'nginx' in service_name.lower():
+                            architecture[service_name] = Nginx(clean_service_name(service_name))
                         elif 'placeholder-email' in service_name.lower():
                             architecture[service_name] = SimpleEmailServiceSesEmail(clean_service_name(service_name))
                         elif 'placeholder-dms' in service_name.lower():
